\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{naverlabseurope}

%%======== Package options and base class ========
\RequirePackage{xifthen}
\newboolean{teaser}
\DeclareOption{teaser}{\setboolean{teaser}{true}}
\newboolean{showabstract}
\DeclareOption{showabstract}{\setboolean{showabstract}{true}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{extarticle}}
\ProcessOptions
\LoadClass{extarticle}

%%======== Packages Required ========
% Fonts and language
\AtEndOfClass{\RequirePackage[tracking=smallcaps]{microtype}}
\RequirePackage[utf8]{inputenc}
\RequirePackage[english]{babel}
\RequirePackage{amsthm, amsmath, amssymb}
\RequirePackage{amsfonts}
\RequirePackage{cmap}
\RequirePackage[T1]{fontenc}
\RequirePackage{url}
\RequirePackage[colorlinks=true, allcolors=blue, backref=page]{hyperref}
\RequirePackage{pifont}
\RequirePackage[dvipsnames]{xcolor}
\RequirePackage{textcomp} % For copyright symbol styling
\RequirePackage[overload]{textcase}
%\RequirePackage{balance}
%% *Graphics, tables and other formatting
\RequirePackage{graphicx}
\RequirePackage{colortbl}
\RequirePackage{booktabs}
\RequirePackage{changepage}
\RequirePackage{enumitem} % For reducing bullet list item separation
\RequirePackage{tabularx}
\RequirePackage{datetime}
% Headers and footers
\RequirePackage{fancyhdr}  % custom headers/footers
\RequirePackage{lastpage}  % Number of pages in the document
% Lists and their spacing
\RequirePackage{enumitem}
\setlist[itemize]{noitemsep}
\setlist[enumerate]{noitemsep}
% Title, Abstract, Bibliography
\RequirePackage[explicit]{titlesec}
\RequirePackage{bibentry}
\RequirePackage{mdframed}
\RequirePackage{caption}
\RequirePackage{needspace}
\RequirePackage[numbers,sort]{natbib}
\RequirePackage{parskip}

% Use Bitstream Charter as the main font. Does not include a typewriter font.
\RequirePackage{XCharter}
\RequirePackage[xcharter,bigdelims,vvarbb]{newtxmath}

% Use the typewriter font from lmodern, scaled up to match Charter's xheight.
% You may wish to add the "p" option to use the proportional font instead of
% the monospaced one, which might look nicer in cases where you do not need
% aligned columns
\RequirePackage[scaled=1.1]{zlmtt}

%%======== Margins and column spacing ========
\RequirePackage[
left=2cm,
right=2cm,
top=2.5cm,
bottom=2.5cm,
headheight=40pt,%
headsep=20pt,%
%showframe, % for testing
a4paper]{geometry}%
\setlength{\columnsep}{15pt} % Distance between the two columns of text
\setlength{\parskip}{0.5\baselineskip}

%% Authors etc...
\def\authors#1{\def\@authors{#1}}
\def\affiliations#1{\def\@affiliations{#1}}
\def\contributions#1{\def\@contributions{#1}}
\def\website#1{\def\@website{#1}}
\def\teaserfig#1{\def\@teaserfig{#1}}
\def\teasercaption#1{\def\@teasercaption{#1}}
\StrLen{@authors}[\authorslen]
\StrLen{@affiliations}[\affiliationslen]
\StrLen{@contributions}[\contributionslen]
\StrLen{@website}[\websitelen]
\def\websiteref#1{\def\@websiteref{#1}}
\def\mythresh{1}
\newcommand{\authsep}{  }

\newlength{\vspaceteaserabove}
\setlength{\vspaceteaserabove}{0mm}
\newlength{\vspaceteaserbelow}
\setlength{\vspaceteaserbelow}{0mm}
\newlength{\vspaceteaserabovecaption}
\setlength{\vspaceteaserabovecaption}{0mm}

%% *Custom font sizes and styles
\newcommand{\absfont}{\linespread{1.2}\fontsize{11}{12}\selectfont}
\newcommand{\headerfont}{\normalfont\sffamily\fontsize{8}{10}\selectfont}
\newcommand{\footerfont}{\color{black}\normalfont\fontsize{8}{10}\selectfont}
\newcommand{\titlefooterfont}{\color{black}\normalfont\fontsize{9}{11}\selectfont}
\newcommand{\headingfont}{\color{black}\large\bf\fontsize{11}{14}\selectfont}
\newcommand{\datefont}{\color{black}\normalfont\fontsize{9}{10}\selectfont}
\newcommand{\copyrightfont}{\color{black}\bfseries\fontsize{8}{10}\selectfont} % should be semi-bold
\newcommand{\titlefont}{\linespread{1.2}\color{black}\normalfont\bfseries\fontsize{18}{22}\selectfont}
\newcommand\authfont{\linespread{1.1}\color{black}\normalfont\bfseries\fontsize{10}{12}\selectfont}
\newcommand\affilfont{\linespread{1.1}\color{black}\normalfont\fontsize{9}{11}\selectfont}
\newcommand\contribfont{\linespread{1.1}\color{black}\normalfont\fontsize{9}{11}\selectfont}
\newcommand\websitefont{\color{blue}\fontsize{9}{11}\selectfont}
\newcommand{\sectionfont}{\color{black}\large\bf\fontsize{12}{14}\selectfont}
\newcommand{\subsectionfont}{\color{black}\large\bf\fontsize{11}{14}\selectfont}


\newtoks\correspondingauthor
\newtoks\paperurl
\newtoks\reportnumber

% Date
\newdateformat{monthyeardate}{\monthname[\THEMONTH], \THEYEAR}
\setcounter{secnumdepth}{3}

\newcommand{\copyrightext}{\copyrightfont \textcopyright \the\year{} NAVER LABS Europe. All rights reserved}

%%======== Header and Footer Content ========
%
% Header and Footer for the first page
\pagestyle{fancy}   % Enables the custom headers/footers
\fancypagestyle{firststyle}{
	\fancyhead[L]{
		{
        \includegraphics[width=160pt]{NLE_1_logo.png}
        \vskip2pt
	 }{}
}
\fancyhead[R]{\datefont\monthyeardate\today \vskip1pt}
\fancyhead[C]{}
\fancyfoot[L]{
	\ifdefined\correspondingauthor
	\if\relax\the\correspondingauthor\relax
    \else \footerfont  {Corresponding author(s): \the\correspondingauthor \\} \fi
	\else \vskip6pt \fi
    % \copyrightext
}
% \fancyfoot[R]{\footerfont \thepage}
\fancyfoot[R]{}
\fancyfoot[C]{\footerfont\bfseries\relax}}

% Header and Footer for pages from 2 onwards
\fancyhead[L,R]{}
\makeatletter
\fancyhead[C]{\titlefooterfont \@title}
\makeatother
\fancyfoot[C]{}
\fancyfoot[L]{}
% \fancyfoot[L]{\vskip6pt \copyrightext}
\fancyfoot[R]{\vskip0pt \footerfont \thepage}

% Header and footer rules (coloured).
\renewcommand{\headrulewidth}{1pt}
\renewcommand{\footrulewidth}{1pt}
\renewcommand{\headrule}{
    \hskip0.025\textwidth\rule{0.95\textwidth}{\headrulewidth}
}
\renewcommand{\footrule}{
    \hskip0.025\textwidth\rule{0.95\textwidth}{\headrulewidth}
}



\renewenvironment{abstract}
{\par\noindent\\  \ignorespaces \bfseries}
{\par\bigskip}

%%========  Bibliography using bibtex ========
\setlength{\bibsep}{1pt plus 1pt minus 1pt}
\setcitestyle{citesep={,\hskip-2pt}}

%% Abstract formatting
\def\xabstract{abstract}
\long\def\abstract#1\end#2{\def\two{#2}\ifx\two\xabstract
	\long\gdef\theabstract{\ignorespaces#1}
	\def\go{\end{abstract}}\else
\typeout{^^J^^J PLEASE DO NOT USE ANY \string\begin\space \string\end^^J
	COMMANDS WITHIN ABSTRACT^^J^^J}#1\end{#2}
\gdef\theabstract{\vskip12pt BADLY FORMED ABSTRACT: PLEASE DO
NOT USE {\tt\string\begin...\string\end} COMMANDS WITHIN
THE ABSTRACT\vskip12pt}\let\go\relax\fi
\go}

% Define an environment with abstract content and styling
\makeatletter
\newcommand{\abscontent}{
    \ifthenelse{\boolean{showabstract}}
                {
                \noindent
                \parbox{\dimexpr\linewidth}{\sectionfont \raggedright Abstract}
                \vskip10pt
	          \parbox{\dimexpr\linewidth}{\absfont\theabstract}
                }
                {
                \noindent
                % \parbox{\dimexpr\linewidth}{\sectionfont \raggedright}
                \vskip10pt
	          \parbox{\dimexpr\linewidth}{\absfont\theabstract}
                }
}

\renewcommand{\maketitle}{
	\twocolumn[
	% \begin{adjustwidth}{0pt}{100pt}
		\begin{center}
			{
                % Title
				{ 
                \raggedright \titlefont \@title \par
                \vskip10pt
                }
                % Authors
                \ifthenelse{\authorslen > \mythresh}{
                   \raggedright \authfont \@authors \par
	          }{}
                % Affiliations
                \ifthenelse{\affiliationslen > \mythresh}{
                   \raggedright \affilfont \@affiliations \par
	          }{}
				% Contributions
                \ifthenelse{\contributionslen > \mythresh}{
                   \raggedright \contribfont \@contributions \par
	          }{}
                % Teaser figure
                \ifthenelse{\boolean{teaser}}
                {
                    \vskip5pt
                    \vspace*{\vspaceteaserabove}
                    \centering
                    \@teaserfig
                    \vspace*{\vspaceteaserabovecaption}
                    \captionof{table}{\@teasercaption} \par
                    \vspace*{\vspaceteaserbelow}
                }
                {}
			\vskip10pt
			}
		\end{center}
	% \end{adjustwidth}
		\abscontent
	\vskip20pt%
	]
	\thispagestyle{firststyle}
}

\titleformat{\section}
{\sectionfont}
{\thesection.}
{0.5em}
{#1}
[]

\titleformat{\subsection}
{\subsectionfont}
{\thesubsection.}
{0.5em}
{#1}
[]

\titlespacing*{\section}{0pc}{10pt}{2pt}
\titlespacing*{\subsection}{0pc}{10pt}{2pt}

\linespread{1.1}